{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2015-2018 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}
{%- extends 'invenio_access/base.html' %}

{%- block page_body %}
    You are not logged in. Your user doesn't have any allowed action.
    <p><a href="{{url_for_security('login')}}">Login</a></p>
{%- endblock %}
