{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2015-2018 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8" />
  </head>
  <body>
    <ul>
        <li><a href="{{ url_for('.index') }}">Home (Open to everyone)</a></li>
        <li><a href="{{ url_for('.role_admin') }}">Role admin (Only users with role 'admin') </a></li>
        <li><a href="{{ url_for('.action_open') }}">Action open (Only users with action 'open' allowed)</a></li>
        <li><a href="{{ url_for('.action_read') }}">Action read (Only users with action 'read' allowed)</a></li>
    </ul>

    {%- block page_body %}{%- endblock page_body %}
    <p>The current application is using the following actions (<span style="color: green">greens</span> are allowed, <span style="color: red">reds</span> are denied for the current user):</p>
    <ul>
        {% for action in actions.keys() %}
            {% if actions[action] %}
                <li style="color: green">{{action}}</li>
            {% else: %}
                <li style="color: red">{{action}}</li>
            {% endif %}
        {% endfor %}
    </ul>
  </body>
</html>
